function [tpRate fpRate] = runAdaBoost(allFeatures, featuresToUse, labelType)
% run adaBoost on a given selection of features for a given label type, and
% return the true positive and false positive rates for each class (as
% measured using leave-one-out cross-validation).
%
% adaBoost is a binary classifier, and therefore the performance is per class
% (as opposed to over the whole set).
%
% Outputs: 
%   tpRate          = number of true results found over total number in set
%   fpRate          = number of false positives over total negative examples
%
% Inputs:
%   allFeatures     = all features structure (project standard)
%   featuresToUse   = vectors of features to select from all features
%   labelType       = which label to train/test on:
%           'type'
%           'location'
%           'playerID'


featuresMat = allFeatures.featureMatrix(:,featuresToUse);
MaxIter = 100;

switch labelType
    case 'type'
        if(isfield(allFeatures.labels,'pitchType'))
            labels = allFeatures.labels.pitchType';
        else
            labels = allFeatures.labels.type;
        end
    case 'location'
        labels = allFeatures.labels.location';
    case 'playerID'
        labels = allFeatures.labels.player_ID';
end

uniqueLabels = unique(labels);

for j = 1:length(uniqueLabels)
    boostLabels = labels;
    boostLabels(boostLabels~=uniqueLabels(j))=-1;
    boostLabels(boostLabels==uniqueLabels(j))= 1;
    j
    for i = 1:length(boostLabels)
        i
        % constructing weak learner
        weak_learner = tree_node_w(3); % pass the number of tree splits to the constructor
        
        % leave one out:
        featureSubset = featuresMat;
        featureSubset(i,:)=[];
        labelSubset = boostLabels;
        labelSubset(i) = [];

        % training with Gentle AdaBoost
        [RLearners RWeights] = RealAdaBoost(weak_learner, featureSubset', labelSubset, MaxIter);
        % evaluating on other one
        predicted_label(i) = sign(Classify(RLearners, RWeights, featuresMat(i,:)'));
        
        clear weak_learner RLearners RWeights ResultR
    end
    
    found = find(predicted_label==1);
    reality = find(boostLabels==1);
    fp = 0;
    tp = 0;
    for i = 1:length(found)
        if( find(reality == found(i)))
            tp = tp + 1;
        else
            fp = fp + 1;
        end
    end

    tpRate(j) = tp ./ length(reality);
    fpRate(j) = fp ./ (length(labels)-length(reality));
end

tpRate = [uniqueLabels tpRate'];
fpRate = [uniqueLabels fpRate'];
