function eL1O = runKNN(allFeatures,k, distance, featuresToUse, labelType)
% use for pitchers: [41, 45, 210 91 96 103]
% test kNN with leave-one-out
%
% Inputs:
%   allFeatures     = all features structure (project standard)
%   featuresToUse   = vectors of features to select from all features
%   labelType       = which label to train/test on:
%           'type'
%           'location'
%           'playerID'

featuresMat = allFeatures.featureMatrix(:,featuresToUse);

switch labelType
    case 'type'
        if(isfield(allFeatures.labels,'pitchType'))
            labels = allFeatures.labels.pitchType';
        else
            labels = allFeatures.labels.type;
        end
    case 'location'
        labels = allFeatures.labels.location';
    case 'playerID'
        labels = allFeatures.labels.player_ID';
end

for i = 1:length(labels)
    
    % leave one out:
    featureSubset = featuresMat;
    featureSubset(i,:)=[];
    labelSubset = labels;
    labelSubset(i) = [];
    
    % run kNN on the left-out example
    class(i) = knnclassify(featuresMat(i,:),featureSubset,labelSubset, k, distance);
    
    % test the results
    isCorrect(i) = (class(i) == labels(i));
    
end

eL1O = sum(isCorrect)./length(isCorrect);
