function [tpRate fpRate] = runSVM(allFeatures, featuresToUse, labelType)
% run SVM on a given selection of features for a given label type, and
% return the true positive and false positive rates for each class (as
% measured using leave-one-out cross-validation).
%
% SVM is a binary classifier, and therefore the performance is per class
% (as opposed to over the whole set).
%
% Outputs: 
%   tpRate          = number of true results found over total number in set
%   fpRate          = number of false positives over total negative examples
%
% Inputs:
%   allFeatures     = all features structure (project standard)
%   featuresToUse   = vectors of features to select from all features
%   labelType       = which label to train/test on:
%           'type'
%           'location'
%           'playerID'

featuresMat = allFeatures.featureMatrix(:,featuresToUse);

switch labelType
    case 'type'
        if(isfield(allFeatures.labels,'pitchType'))
            labels = allFeatures.labels.pitchType';
        else
            labels = allFeatures.labels.type;
        end
    case 'location'
        labels = allFeatures.labels.location';
    case 'playerID'
        labels = allFeatures.labels.player_ID';
end

uniqueLabels = unique(labels);

for j = 1:length(uniqueLabels)
    fprintf('classifying label %i\n',uniqueLabels(j))
    
    svmLabels = labels;
    svmLabels(svmLabels~=uniqueLabels(j))=-1;
    svmLabels(svmLabels==uniqueLabels(j))= 1;
    
    for i = 1:length(svmLabels)
        % leave one out:
        featureSubset = featuresMat;
        featureSubset(i,:)=[];
        labelSubset = svmLabels;
        labelSubset(i) = [];

        model = svmtrain(labelSubset, featureSubset, '-t 2 -c 50');
        [predicted_label(i), accuracy, decision_values] = svmpredict(svmLabels(i),featuresMat(i,:), model);

        clear model
    end
    
    found = find(predicted_label==1);
    reality = find(svmLabels==1);
    fp = 0;
    tp = 0;
    for i = 1:length(found)
        if( find(reality == found(i)))
            tp = tp + 1;
        else
            fp = fp + 1;
        end
    end

    tpRate(j) = tp ./ length(reality);
    fpRate(j) = fp ./ (length(labels)-length(reality));
end

tpRate = [uniqueLabels' tpRate'];
fpRate = [uniqueLabels' fpRate'];





