function [hand,forearm,upper_arm,chest,waist] = getData(GESTURE_ID)

% Get high and low range data for a given GESTURE_ID at each of 5
% node locations: 1 = hand, 2 = forearm, 3 = upper arm, 4 = chest, 5 = waist.

clc;
conn = database('sox2010odbc','sox','s0xs0x');
a = isconnection(conn);

START_IND = 10;
STOP_IND  = 7800;

for NL = 1:5
  
  query = sprintf('SELECT "SAMPLE_NUMBER", "LO_X", "LO_Y", "LO_Z", "LO_PITCH", "LO_ROLL", "LO_YAW" FROM "CALIB_LOW_GESTURE_DATA2010" WHERE "PLAYER_GESTURES_SEQ_ID" = %g AND "NODE_LOCATION" = %g AND "SAMPLE_NUMBER" > %g AND "SAMPLE_NUMBER" < %g ORDER BY "SAMPLE_NUMBER" ASC', GESTURE_ID, NL, START_IND, STOP_IND);
  lo=exec(conn,query);
  lresults=fetch(lo);  
  
  if strcmp(cell2mat(lresults.Data),'No Data') == 0
    LO_SAMP = cell2mat(lresults.Data(:,1)); 
    LO_X    = cell2mat(lresults.Data(:,2)); 
    LO_Y    = cell2mat(lresults.Data(:,3)); 
    LO_Z    = cell2mat(lresults.Data(:,4)); 
    LO_PI   = cell2mat(lresults.Data(:,5)); 
    LO_RO   = cell2mat(lresults.Data(:,6)); 
    LO_YA   = cell2mat(lresults.Data(:,7)); 
  else
    fprintf('No LO data');
    LO_SAMP = []; LO_X = []; LO_Y = []; LO_Z = [];
    LO_PI = []; LO_RO = []; LO_YA = [];
  end;
  
  clear query results;
  
  query = sprintf('SELECT "SAMPLE_NUMBER", "HI_X", "HI_Y", "HI_Z", "HI_PITCH", "HI_ROLL", "HI_YAW" FROM "CALIB_GESTURE_DATA2010" WHERE "PLAYER_GESTURES_SEQ_ID" = %g AND "NODE_LOCATION" = %g AND "SAMPLE_NUMBER" > %g AND "SAMPLE_NUMBER" < %g ORDER BY "SAMPLE_NUMBER" ASC', GESTURE_ID, NL, START_IND, STOP_IND);
  
  hi=exec(conn,query);
  hresults=fetch(hi);
  if strcmp(cell2mat(hresults.Data),'No Data') == 0
    HI_SAMP = cell2mat(hresults.Data(:,1)); 
    HI_X    = cell2mat(hresults.Data(:,2)); 
    HI_Y    = cell2mat(hresults.Data(:,3)); 
    HI_Z    = cell2mat(hresults.Data(:,4)); 
    HI_PI   = cell2mat(hresults.Data(:,5)); 
    HI_RO   = cell2mat(hresults.Data(:,6)); 
    HI_YA   = cell2mat(hresults.Data(:,7)); 
  else
    fprintf('No HI data');
    HI_SAMP = []; HI_X = []; HI_Y = []; HI_Z = [];
    HI_PI = []; HI_RO = []; HI_YA = [];
  end;
  
  if NL == 1
    hand = struct('HI_SAMP',HI_SAMP,'HI_X',HI_X,'HI_Y',HI_Y,'HI_Z',HI_Z,'HI_PI',HI_PI,'HI_RO',HI_RO,'HI_YA',HI_YA,'LO_SAMP',LO_SAMP,'LO_X',LO_X,'LO_Y',LO_Y,'LO_Z',LO_Z,'LO_PI',LO_PI,'LO_RO',LO_RO,'LO_YA',LO_YA);
  elseif NL == 2  
    forearm = struct('HI_SAMP',HI_SAMP,'HI_X',HI_X,'HI_Y',HI_Y,'HI_Z',HI_Z,'HI_PI',HI_PI,'HI_RO',HI_RO,'HI_YA',HI_YA,'LO_SAMP',LO_SAMP,'LO_X',LO_X,'LO_Y',LO_Y,'LO_Z',LO_Z,'LO_PI',LO_PI,'LO_RO',LO_RO,'LO_YA',LO_YA);              
  elseif NL == 3
    upper_arm = struct('HI_SAMP',HI_SAMP,'HI_X',HI_X,'HI_Y',HI_Y,'HI_Z',HI_Z,'HI_PI',HI_PI,'HI_RO',HI_RO,'HI_YA',HI_YA,'LO_SAMP',LO_SAMP,'LO_X',LO_X,'LO_Y',LO_Y,'LO_Z',LO_Z,'LO_PI',LO_PI,'LO_RO',LO_RO,'LO_YA',LO_YA);              
  elseif NL == 4
    chest = struct('HI_SAMP',HI_SAMP,'HI_X',HI_X,'HI_Y',HI_Y,'HI_Z',HI_Z,'HI_PI',HI_PI,'HI_RO',HI_RO,'HI_YA',HI_YA,'LO_SAMP',LO_SAMP,'LO_X',LO_X,'LO_Y',LO_Y,'LO_Z',LO_Z,'LO_PI',LO_PI,'LO_RO',LO_RO,'LO_YA',LO_YA);
  else
    waist = struct('HI_SAMP',HI_SAMP,'HI_X',HI_X,'HI_Y',HI_Y,'HI_Z',HI_Z,'HI_PI',HI_PI,'HI_RO',HI_RO,'HI_YA',HI_YA,'LO_SAMP',LO_SAMP,'LO_X',LO_X,'LO_Y',LO_Y,'LO_Z',LO_Z,'LO_PI',LO_PI,'LO_RO',LO_RO,'LO_YA',LO_YA);
  end;
  
end;

close(conn);