function [gesture_ID_list, player_ID_list, session_ID_list] = getGestures(player_type,type,location,right_left,player_ID)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This script produces lists of gestures along with the players
% and sessions that produced them that are described by the input 
%descriptions.
%
%
% Outputs: 
%  gesture_ID_list - gesture_IDs that satisfy input classification.
%  player_ID_list  - player_ID for each gesture in the list. 
%  session_ID_list  - session_ID for each gesture in the list. 
% 
%
% Inputs:
% player_type = 1 if pitcher, 2 if hitter 
%
% Pitchers:
% types = 0 if UNKNOWN, 1 if FAST, 2 if CHANGE, 3 if CURVE, 4 if SLIDER,
% 5 if 2_SEAM, 6 if 4_SEAM, 7 if BREAK
% location = [10 1 2 3 13; 11 4 5 6 14; 12 7 8 9 15]; 16 if dirt
% right_left = r if right, l if left
%
% Batters:
% types = 0 if STRIKE, 1 if FREE, 2 if TEE, 3 if SOFT, 4 if BP, 5 if NORMAL 
% location = 1 if center, 2 if left, 3 if right
% right_left = 'R' if right, 'L' if left
%
%
% Notes:
% If type or location = 'all' these are not constrained in query
% right_left and player_ID are only constrained if defined.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clc;
conn = database('sox2010odbc','sox','s0xs0x');
a = isconnection(conn);

session_ID1     = [];
player_ID2      = []; 
gesture_ID_list = [];
player_ID_list  = [];
session_ID_list = [];

if player_type == 1    % Pitching %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  
  if exist('player_ID') == 1
    player_ID1 = player_ID;
  else
    if exist('right_left') == 1 
      query1 = sprintf('SELECT "PLAYER_SEQ_ID" FROM "PLAYER_INFO2010" WHERE "PLAYER_TYPE"= 1 AND "PLAYER_THROW_R_L"= ''%c''', right_left);
    else
      query1 = sprintf('SELECT "PLAYER_SEQ_ID" FROM "PLAYER_INFO2010" WHERE "PLAYER_TYPE"=1');
    end;
    q1 = exec(conn, query1);
    results1 = fetch(q1);
    if strcmp(cell2mat(results1.Data),'No Data') == 0
      player_ID1 = cell2mat(results1.Data);
    else
      fprintf('No data.\n');
      return;
    end;
  end;  
  
  for i=1:length(player_ID1)
    query2 = sprintf('SELECT "PLAYER_SESSIONS_SEQ_ID" FROM "PLAYER_SESSIONS2010" WHERE "PLAYER_SEQ_ID" = %g', player_ID1(i));
    q2 = exec(conn, query2);
    results2 = fetch(q2);
    if strcmp(cell2mat(results2.Data),'No Data') == 0
      session_ID1 = cat(1,session_ID1,cell2mat(results2.Data));
      player_ID2  = cat(1,player_ID2,player_ID1(i)*(ones(size(cell2mat(results2.Data))))); 
    end;
  end;  
  
  if length(session_ID1) == 0
    fprintf('No data.\n');
    return;
  end;

  for j=1:length(session_ID1) 
    if strcmp(type, 'all') == 1 && strcmp(location, 'all') == 1
      query3 = sprintf('SELECT "PLAYER_GESTURES_SEQ_ID" FROM "PLAYER_GESTURES2010" WHERE "PLAYER_SESSIONS_SEQ_ID"= %g AND "GESTURE_TYPE"= 1',session_ID1(j)); 
    else      
      if strcmp(type, 'all') == 1
        query3 = sprintf('SELECT "PLAYER_GESTURES_SEQ_ID" FROM "PLAYER_GESTURES2010" WHERE "PLAYER_SESSIONS_SEQ_ID"=%g AND "GESTURE_TYPE"= 1 AND "PITCH_LOCATION"=%g',session_ID1(j),location);
      elseif strcmp(location,'all') == 1
        query3 = sprintf('SELECT "PLAYER_GESTURES_SEQ_ID" FROM "PLAYER_GESTURES2010" WHERE "PLAYER_SESSIONS_SEQ_ID"=%g AND "GESTURE_TYPE"= 1 AND "PITCH_TYPE"=%g',session_ID1(j),type);      
      else  
      query3 = sprintf('SELECT "PLAYER_GESTURES_SEQ_ID" FROM "PLAYER_GESTURES2010" WHERE "PLAYER_SESSIONS_SEQ_ID"=%g AND "GESTURE_TYPE"= 1 AND "PITCH_TYPE"= %g AND "PITCH_LOCATION"=%g',session_ID1(j),type,location);
      end;
    end;
    q3 = exec(conn, query3);
    results3 = fetch(q3);
    if strcmp(cell2mat(results3.Data),'No Data') == 0
      gesture_ID_list = cat(1,gesture_ID_list,cell2mat(results3.Data(:,1)));
      player_ID_list = cat(1,player_ID_list,player_ID2(j)*ones(size(cell2mat(results3.Data))));
      session_ID_list = cat(1,session_ID_list,session_ID1(j)*ones(size(cell2mat(results3.Data))));
    end;
  end;  

  if length(gesture_ID_list) == 0
    fprintf('No data.\n');
    return;
  end; 
  
elseif player_type == 2  % Batting %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 

  if exist('player_ID') == 1
    player_ID1 = player_ID;
  else
    if exist('right_left') == 1 
      query1 = sprintf('SELECT "PLAYER_SEQ_ID" FROM "PLAYER_INFO2010" WHERE "PLAYER_TYPE" = 2 AND "PLAYER_BAT_R_L" = ''%c''', right_left);
    else
      query1 = sprintf('SELECT "PLAYER_SEQ_ID" FROM "PLAYER_INFO2010" WHERE "PLAYER_TYPE" = 2');
    end;
    q1 = exec(conn, query1);
    results1 = fetch(q1);
    if strcmp(cell2mat(results1.Data),'No Data') == 0
      player_ID1 = cell2mat(results1.Data);
    else
      fprintf('No data.\n');
      return;
    end;
  end;  
  
  for i=1:length(player_ID1)
    query2 = sprintf('SELECT "PLAYER_SESSIONS_SEQ_ID" FROM "PLAYER_SESSIONS2010" WHERE "PLAYER_SEQ_ID" = %g', player_ID1(i));
    q2 = exec(conn, query2);      
    results2 = fetch(q2);
    if strcmp(cell2mat(results2.Data),'No Data') == 0 
      session_ID1 = cat(1,session_ID1,cell2mat(results2.Data));
      player_ID2  = cat(1,player_ID2,player_ID1(i)*(ones(size(cell2mat(results2.Data))))); 
    end;  
  end;

  if length(session_ID1) == 0
    fprintf('No data.\n');
    return;
  end;   
    
  for j=1:length(session_ID1) 
    if strcmp(type, 'all') == 1 && strcmp(location, 'all') == 1
      query3 = sprintf('SELECT "PLAYER_GESTURES_SEQ_ID" FROM "PLAYER_GESTURES2010" WHERE "PLAYER_SESSIONS_SEQ_ID"= %g AND "GESTURE_TYPE"= 2',session_ID1(j)); 
    else      
      if strcmp(type, 'all') == 1
        query3 = sprintf('SELECT "PLAYER_GESTURES_SEQ_ID" FROM "PLAYER_GESTURES2010" WHERE "PLAYER_SESSIONS_SEQ_ID"=%g AND "GESTURE_TYPE"= 2 AND "HIT_LOCATION"=%g',session_ID1(j),location);
      elseif strcmp(location,'all') == 1
        query3 = sprintf('SELECT "PLAYER_GESTURES_SEQ_ID" FROM "PLAYER_GESTURES2010" WHERE "PLAYER_SESSIONS_SEQ_ID"=%g AND "GESTURE_TYPE"= 2 AND "SWING_TYPE"=%g',session_ID1(j),type);      
      else  
      query3 = sprintf('SELECT "PLAYER_GESTURES_SEQ_ID" FROM "PLAYER_GESTURES2010" WHERE "PLAYER_SESSIONS_SEQ_ID"=%g AND "GESTURE_TYPE"= 2 AND "SWING_TYPE"= %g AND "HIT_LOCATION"=%g',session_ID1(j),type,location);
      end;
    end;
    q3 = exec(conn, query3);
    results3 = fetch(q3); 
    if strcmp(cell2mat(results3.Data),'No Data') == 0
      gesture_ID_list = cat(1,gesture_ID_list,cell2mat(results3.Data));
      player_ID_list  = cat(1,player_ID_list,player_ID2(j)*ones(size(cell2mat(results3.Data))));
      session_ID_list = cat(1,session_ID_list,session_ID1(j)*ones(size(cell2mat(results3.Data))));
    end;
  end;  
  
  if length(gesture_ID_list) == 0
    fprintf('No data.\n');
    return;
  end;   
  
else
  fprintf('Player type error.');
end;

close(conn);