function features = extractFeatures(rawData)
% features = extractFeatures(dataExample)
%
% Extracts features from raw data 
%
% Output: 
%   features    = row vector of features
%
% Inputs:
%   rawData     = struct containing raw data, of the form:
%                   hand: [1x1 struct]
%                   forearm: [1x1 struct]
%                   upper_arm: [1x1 struct]
%                   chest: [1x1 struct]
%                   waist: [1x1 struct]
%

% pull raw data out of the struct
hand = rawData.hand;
forearm = rawData.forearm;
upper_arm = rawData.upper_arm;
chest = rawData.chest;
waist = rawData.waist;

% set origin to be absolute peak of hand z-axis
[val_ref ind_ref] = max(abs(hand.HI_Z));
hand_origin = hand.HI_SAMP(ind_ref);
chest_origin = findOrigin(chest.LO_SAMP, hand_origin);
waist_origin = findOrigin(waist.LO_SAMP, hand_origin);
forearm_origin = findOrigin(forearm.HI_SAMP, hand_origin);
upper_arm_origin = findOrigin(upper_arm.HI_SAMP, hand_origin);

%ata = {chest.LO_X chest.LO_Y chest.LO_Z chest.LO_PI chest.LO_RO chest.LO_YA forearm.HI_X forearm.HI_Y forearm.HI_Z forearm.HI_PI forearm.HI_RO forearm.HI_YA hand.HI_X hand.HI_Y hand.HI_Z hand.HI_PI hand.HI_RO hand.HI_YA upper_arm.HI_X upper_arm.HI_Y upper_arm.HI_Z upper_arm.HI_PI upper_arm.HI_RO upper_arm.HI_YA waist.LO_X waist.LO_Y waist.LO_Z waist.LO_PI waist.LO_RO waist.LO_YA};
%samp = {chest.LO_SAMP chest.LO_SAMP chest.LO_SAMP chest.LO_SAMP chest.LO_SAMP chest.LO_SAMP forearm.HI_SAMP forearm.HI_SAMP forearm.HI_SAMP forearm.HI_SAMP forearm.HI_SAMP forearm.HI_SAMP hand.HI_SAMP hand.HI_SAMP hand.HI_SAMP hand.HI_SAMP hand.HI_SAMP hand.HI_SAMP upper_arm.HI_SAMP upper_arm.HI_SAMP upper_arm.HI_SAMP upper_arm.HI_SAMP upper_arm.HI_SAMP upper_arm.HI_SAMP waist.LO_SAMP waist.LO_SAMP waist.LO_SAMP waist.LO_SAMP waist.LO_SAMP waist.LO_SAMP};


% ------------------------
% time domain
% find nPeaks tallest peaks and sample indices, sorted descending by height
nPeaks = 1;

%   forearm:
[peaks_forearm_x locs_forearm_x] = fp(forearm.HI_X, forearm.HI_SAMP, nPeaks);
[peaks_forearm_y locs_forearm_y] = fp(forearm.HI_Y, forearm.HI_SAMP, nPeaks);
[peaks_forearm_z locs_forearm_z] = fp(forearm.HI_Z, forearm.HI_SAMP, nPeaks);
[peaks_forearm_pi locs_forearm_pi] = fp(forearm.HI_PI, forearm.HI_SAMP, nPeaks);
[peaks_forearm_ro locs_forearm_ro] = fp(forearm.HI_RO, forearm.HI_SAMP, nPeaks);
[peaks_forearm_ya locs_forearm_ya] = fp(forearm.HI_YA, forearm.HI_SAMP, nPeaks);

%   hand:
[peaks_hand_x locs_hand_x] = fp(hand.HI_X, hand.HI_SAMP, nPeaks);
[peaks_hand_y locs_hand_y] = fp(hand.HI_Y, hand.HI_SAMP, nPeaks);
[peaks_hand_pi locs_hand_pi] = fp(hand.HI_PI, hand.HI_SAMP, nPeaks);
[peaks_hand_ro locs_hand_ro] = fp(hand.HI_RO, hand.HI_SAMP, nPeaks);
[peaks_hand_ya locs_hand_ya] = fp(hand.HI_YA, hand.HI_SAMP, nPeaks);

%   upper arm:
[peaks_upper_arm_x locs_upper_arm_x] = fp(upper_arm.HI_X, upper_arm.HI_SAMP, nPeaks);
[peaks_upper_arm_y locs_upper_arm_y] = fp(upper_arm.HI_Y, upper_arm.HI_SAMP, nPeaks);
[peaks_upper_arm_z locs_upper_arm_z] = fp(upper_arm.HI_Z, upper_arm.HI_SAMP, nPeaks);
[peaks_upper_arm_pi locs_upper_arm_pi] = fp(upper_arm.HI_PI, upper_arm.HI_SAMP, nPeaks);
[peaks_upper_arm_ro locs_upper_arm_ro] = fp(upper_arm.HI_RO, upper_arm.HI_SAMP, nPeaks);
[peaks_upper_arm_ya locs_upper_arm_ya] = fp(upper_arm.HI_YA, upper_arm.HI_SAMP, nPeaks);

% chest and waist are commented to reduce the dimensionality of the feature space
%   chest:
% [peaks_chest_x locs_chest_x] = fp(chest.LO_X, chest.LO_SAMP, nPeaks);
% [peaks_chest_y locs_chest_y] = fp(chest.LO_Y, chest.LO_SAMP, nPeaks);
% [peaks_chest_z locs_chest_z] = fp(chest.LO_Z, chest.LO_SAMP, nPeaks);
% [peaks_chest_pi locs_chest_pi] = fp(chest.LO_PI, chest.LO_SAMP, nPeaks);
% [peaks_chest_ro locs_chest_ro] = fp(chest.LO_RO, chest.LO_SAMP, nPeaks);
% [peaks_chest_ya locs_chest_ya] = fp(chest.LO_YA, chest.LO_SAMP, nPeaks);

%   waist:
% [peaks_waist_x locs_waist_x] = fp(waist.LO_X, waist.LO_SAMP, nPeaks);
% [peaks_waist_y locs_waist_y] = fp(waist.LO_Y, waist.LO_SAMP, nPeaks);
% [peaks_waist_z locs_waist_z] = fp(waist.LO_Z, waist.LO_SAMP, nPeaks);
% [peaks_waist_pi locs_waist_pi] = fp(waist.LO_PI, waist.LO_SAMP, nPeaks);
% [peaks_waist_ro locs_waist_ro] = fp(waist.LO_RO, waist.LO_SAMP, nPeaks);
% [peaks_waist_ya locs_waist_ya] = fp(waist.LO_YA, waist.LO_SAMP, nPeaks);

% ------------------------
% find distances between peaks and origin
dist_chest = [];%[locs_chest_x ; locs_chest_y ; locs_chest_z ; locs_chest_pi ; locs_chest_ro ; locs_chest_ya] - chest_origin;
dist_waist = [];%[locs_waist_x ; locs_waist_y ; locs_waist_z ; locs_waist_pi ; locs_waist_ro ; locs_waist_ya] - waist_origin;
dist_forearm = [locs_forearm_x ; locs_forearm_y ; locs_forearm_z ; locs_forearm_pi ; locs_forearm_ro ; locs_forearm_ya] - forearm_origin;
dist_hand = [locs_hand_x ; locs_hand_y ; locs_hand_pi ; locs_hand_ro ; locs_hand_ya] - hand_origin;
dist_upper_arm = [locs_upper_arm_x ; locs_upper_arm_y ; locs_upper_arm_z ; locs_upper_arm_pi ; locs_upper_arm_ro ; locs_upper_arm_ya] - upper_arm_origin;
dists = [dist_chest ; dist_waist ; dist_forearm ; dist_hand ; dist_upper_arm];

% ------------------------
% compute ratios between rectified peak heights and hand.HI_Z
ratio_chest = [];%[peaks_chest_x ; peaks_chest_y ; peaks_chest_z ; peaks_chest_pi ; peaks_chest_ro ; peaks_chest_ya] ./ val_ref;
ratio_waist = [];%[peaks_waist_x ; peaks_waist_y ; peaks_waist_z ; peaks_waist_pi ; peaks_waist_ro ; peaks_waist_ya] ./ val_ref;
ratio_forearm = [peaks_forearm_x ; peaks_forearm_y ; peaks_forearm_z ; peaks_forearm_pi ; peaks_forearm_ro ; peaks_forearm_ya] ./ val_ref;
ratio_hand = [peaks_hand_x ; peaks_hand_y ; peaks_hand_pi ; peaks_hand_ro ; peaks_hand_ya] ./ val_ref;
ratio_upper_arm = [peaks_upper_arm_x ; peaks_upper_arm_y ; peaks_upper_arm_z ; peaks_upper_arm_pi ; peaks_upper_arm_ro ; peaks_upper_arm_ya] ./ val_ref;
ratios = [ratio_chest ; ratio_waist ; ratio_forearm ; ratio_hand ; ratio_upper_arm];


% ------------------------
% frequency domain
nSpectPeaks = 1;

% L = 128;            % Length of signal window
% fpks_chest_x = findSpectralPeaks(chest.LO_X, chest.LO_SAMP, chest_origin, L, nSpectPeaks, 330);
% fpks_chest_y = findSpectralPeaks(chest.LO_Y, chest.LO_SAMP, chest_origin, L, nSpectPeaks, 330);
% fpks_chest_z = findSpectralPeaks(chest.LO_Z, chest.LO_SAMP, chest_origin, L, nSpectPeaks, 330);
% fpks_chest_pi = findSpectralPeaks(chest.LO_PI, chest.LO_SAMP, chest_origin, L, nSpectPeaks, 330);
% fpks_chest_ro = findSpectralPeaks(chest.LO_RO, chest.LO_SAMP, chest_origin, L, nSpectPeaks, 330);
% fpks_chest_ya = findSpectralPeaks(chest.LO_YA, chest.LO_SAMP, chest_origin, L, nSpectPeaks, 330);
fpks_chest = []; %[fpks_chest_x fpks_chest_y fpks_chest_z fpks_chest_pi fpks_chest_ro fpks_chest_ya];

% L = 128;            % Length of signal window
% fpks_waist_x = findSpectralPeaks(waist.LO_X, waist.LO_SAMP, waist_origin, L, nSpectPeaks, 330);
% fpks_waist_y = findSpectralPeaks(waist.LO_Y, waist.LO_SAMP, waist_origin, L, nSpectPeaks, 330);
% fpks_waist_z = findSpectralPeaks(waist.LO_Z, waist.LO_SAMP, waist_origin, L, nSpectPeaks, 330);
% fpks_waist_pi = findSpectralPeaks(waist.LO_PI, waist.LO_SAMP, waist_origin, L, nSpectPeaks, 330);
% fpks_waist_ro = findSpectralPeaks(waist.LO_RO, waist.LO_SAMP, waist_origin, L, nSpectPeaks, 330);
% fpks_waist_ya = findSpectralPeaks(waist.LO_YA, waist.LO_SAMP, waist_origin, L, nSpectPeaks, 330);
fpks_waist = []; %[fpks_waist_x fpks_waist_y fpks_waist_z fpks_waist_pi fpks_waist_ro fpks_waist_ya];

L = 512;            % Length of signal window
fpks_forearm_x = findSpectralPeaks(forearm.HI_X, forearm.HI_SAMP, forearm_origin, L, nSpectPeaks, 1000);
fpks_forearm_y = findSpectralPeaks(forearm.HI_Y, forearm.HI_SAMP, forearm_origin, L, nSpectPeaks, 1000);
fpks_forearm_z = [];%findSpectralPeaks(forearm.HI_Z, forearm.HI_SAMP, forearm_origin, L, nSpectPeaks, 1000);
fpks_forearm_pi = findSpectralPeaks(forearm.HI_PI, forearm.HI_SAMP, forearm_origin, L, nSpectPeaks, 1000);
fpks_forearm_ro = findSpectralPeaks(forearm.HI_RO, forearm.HI_SAMP, forearm_origin, L, nSpectPeaks, 1000);
fpks_forearm_ya = findSpectralPeaks(forearm.HI_YA, forearm.HI_SAMP, forearm_origin, L, nSpectPeaks, 1000);
fpks_forearm = [fpks_forearm_x fpks_forearm_y fpks_forearm_z fpks_forearm_pi fpks_forearm_ro fpks_forearm_ya];

L = 512;            % Length of signal window
fpks_hand_x = findSpectralPeaks(hand.HI_X, hand.HI_SAMP, hand_origin, L, nSpectPeaks, 1000);
fpks_hand_y = findSpectralPeaks(hand.HI_Y, hand.HI_SAMP, hand_origin, L, nSpectPeaks, 1000);
fpks_hand_z = [];%findSpectralPeaks(hand.HI_Z, hand.HI_SAMP, hand_origin, L, nSpectPeaks, 1000);
fpks_hand_pi = findSpectralPeaks(hand.HI_PI, hand.HI_SAMP, hand_origin, L, nSpectPeaks, 1000);
fpks_hand_ro = findSpectralPeaks(hand.HI_RO, hand.HI_SAMP, hand_origin, L, nSpectPeaks, 1000);
fpks_hand_ya = findSpectralPeaks(hand.HI_YA, hand.HI_SAMP, hand_origin, L, nSpectPeaks, 1000);
fpks_hand = [fpks_hand_x fpks_hand_y fpks_hand_z fpks_hand_pi fpks_hand_ro];% fpks_hand_ya];

L = 512;            % Length of signal window
fpks_upper_arm_x = findSpectralPeaks(upper_arm.HI_X, upper_arm.HI_SAMP, upper_arm_origin, L, nSpectPeaks, 1000);
fpks_upper_arm_y = findSpectralPeaks(upper_arm.HI_Y, upper_arm.HI_SAMP, upper_arm_origin, L, nSpectPeaks, 1000);
fpks_upper_arm_z = [];%findSpectralPeaks(upper_arm.HI_Z, upper_arm.HI_SAMP, upper_arm_origin, L, nSpectPeaks, 1000);
fpks_upper_arm_pi = findSpectralPeaks(upper_arm.HI_PI, upper_arm.HI_SAMP, upper_arm_origin, L, nSpectPeaks, 1000);
fpks_upper_arm_ro = findSpectralPeaks(upper_arm.HI_RO, upper_arm.HI_SAMP, upper_arm_origin, L, nSpectPeaks, 1000);
fpks_upper_arm_ya = findSpectralPeaks(upper_arm.HI_YA, upper_arm.HI_SAMP, upper_arm_origin, L, nSpectPeaks, 1000);
fpks_upper_arm = [fpks_upper_arm_x fpks_upper_arm_y fpks_upper_arm_z fpks_upper_arm_pi fpks_upper_arm_ro fpks_upper_arm_ya];

fpks = [fpks_chest fpks_waist fpks_forearm fpks_hand fpks_upper_arm]';

% ------------------------
% extract yet more features (full-width half-max, energy) 

moreFeatures = [];

% Hand

% Find magnitude of vectors:
h_lin_acc = sqrt(hand.HI_X.^2 + hand.HI_Y.^2 + hand.HI_Z.^2);
h_rot_vel = sqrt(hand.HI_RO.^2 + hand.HI_PI.^2 + hand.HI_YA.^2); 

% Find peak vlaues,times:
[h_val_acc,h_ind_acc] = max(abs(h_lin_acc));   % remember to synch to sample
[h_val_rot,h_ind_rot] = max(abs(h_rot_vel)); 

h_ind_acc = h_ind_acc-ind_ref;
h_ind_rot = h_ind_rot-ind_ref;

% Find FWHM

h_half_ind_acc = find(abs(h_lin_acc) > 0.5*h_val_acc);
h_fwhm_acc     = h_half_ind_acc(end)-h_half_ind_acc(1);

h_half_ind_rot = find(abs(h_rot_vel) > 0.5*h_val_rot);
h_fwhm_rot     = h_half_ind_rot(end)-h_half_ind_rot(1);

% Find total energy in peak (and use it to normalize everything else)
h_e_acc = sum(h_lin_acc.^2);
h_e_rot = sum(h_rot_vel.^2);

moreFeatures = cat(1,moreFeatures,h_fwhm_acc,h_fwhm_rot,h_e_rot,h_e_acc);

% Forearm

% Find magnitude of vectors:
f_lin_acc = sqrt(forearm.HI_X.^2 + forearm.HI_Y.^2 + forearm.HI_Z.^2);
f_rot_vel = sqrt(forearm.HI_RO.^2 + forearm.HI_PI.^2 + forearm.HI_YA.^2); 

% Find peak vlaues,times:
[f_val_acc,f_ind_acc] = max(abs(f_lin_acc));   % remember to synch to sample
[f_val_rot,f_ind_rot] = max(abs(f_rot_vel)); 

f_ind_acc = f_ind_acc-ind_ref;
f_ind_rot = f_ind_rot-ind_ref;

% Find FWHM

f_half_ind_acc = find(abs(f_lin_acc) > 0.5*f_val_acc);
f_fwhm_acc     = f_half_ind_acc(end)-f_half_ind_acc(1);

f_half_ind_rot = find(abs(f_rot_vel) > 0.5*f_val_rot);
f_fwhm_rot     = f_half_ind_rot(end)-f_half_ind_rot(1);

% Find total energy in peak
f_e_acc = sum(f_lin_acc.^2)./10^10;
f_e_rot = sum(f_rot_vel.^2)./10^10;

moreFeatures = cat(1,moreFeatures,f_fwhm_acc,f_fwhm_rot,f_e_acc,f_e_rot);

% Upper Arm

% Find magnitude of vectors:
u_lin_acc = sqrt(upper_arm.HI_X.^2 + upper_arm.HI_Y.^2 + upper_arm.HI_Z.^2);
u_rot_vel = sqrt(upper_arm.HI_RO.^2 + upper_arm.HI_PI.^2 + upper_arm.HI_YA.^2); 

% Find peak vlaues,times:
[u_val_acc,u_ind_acc] = max(abs(u_lin_acc));   % remember to synch to sample
[u_val_rot,u_ind_rot] = max(abs(u_rot_vel)); 

u_ind_acc = u_ind_acc-ind_ref;
u_ind_rot = u_ind_rot-ind_ref;

% Find FWHM

u_half_ind_acc = find(abs(u_lin_acc) > 0.5*u_val_acc);
u_fwhm_acc     = u_half_ind_acc(end)-u_half_ind_acc(1);

u_half_ind_rot = find(abs(u_rot_vel) > 0.5*u_val_rot);
u_fwhm_rot     = u_half_ind_rot(end)-u_half_ind_rot(1);

% Find total energy in peak
u_e_acc = sum(u_lin_acc.^2)./10^10;
u_e_rot = sum(u_rot_vel.^2)./10^10;

moreFeatures = cat(1,moreFeatures,u_fwhm_acc,u_fwhm_rot,u_e_acc,u_e_rot);

% % Chest
% 
% % Find magnitude of vectors:
% c_lin_acc = sqrt(chest.HI_X.^2 + chest.HI_Y.^2 + chest.HI_Z.^2);
% c_rot_vel = sqrt(chest.HI_RO.^2 + chest.HI_PI.^2 + chest.HI_YA.^2); 
% 
% % Find peak vlaues,times:
% [c_val_acc,c_ind_acc] = max(abs(c_lin_acc));   % remember to synch to sample
% [c_val_rot,c_ind_rot] = max(abs(c_rot_vel)); 
% 
% c_ind_acc = c_ind_acc-ind_ref;
% c_ind_rot = c_ind_rot-ind_ref;
% 
% % Find FWHM
% 
% c_half_ind_acc = find(abs(c_lin_acc) > 0.5*c_val_acc);
% c_fwhm_acc     = c_half_ind_acc(end)-c_half_ind_acc(1);
% 
% c_half_ind_rot = find(abs(c_rot_vel) > 0.5*c_val_rot);
% c_fwhm_rot     = c_half_ind_rot(end)-c_half_ind_rot(1);
% 
% % Find total energy in peak
% c_e_acc = sum(c_lin_acc.^2)./10^10;
% c_e_rot = sum(c_rot_vel.^2)./10^10;
% 
% moreFeatures = cat(1,moreFeatures,c_val_acc,c_val_rot,c_ind_acc,c_ind_rot, ...
%                c_fwhm_acc,c_fwhm_rot,c_e_acc,c_e_rot);
% 
% % Waist
% 
% % Find magnitude of vectors:
% w_lin_acc = sqrt(waist.HI_X.^2 + waist.HI_Y.^2 + waist.HI_Z.^2);
% w_rot_vel = sqrt(waist.HI_RO.^2 + waist.HI_PI.^2 + waist.HI_YA.^2); 
% 
% % Find peak vlaues,times:
% [w_val_acc,w_ind_acc] = max(abs(w_lin_acc));   % remember to synch to sample
% [w_val_rot,w_ind_rot] = max(abs(w_rot_vel)); 
% 
% w_ind_acc = w_ind_acc-ind_ref;
% w_ind_rot = w_ind_rot-ind_ref;
% 
% % Find FWHM
% 
% w_half_ind_acc = find(abs(w_lin_acc) > 0.5*w_val_acc);
% w_fwhm_acc     = w_half_ind_acc(end)-w_half_ind_acc(1);
% 
% w_half_ind_rot = find(abs(w_rot_vel) > 0.5*w_val_rot);
% w_fwhm_rot     = w_half_ind_rot(end)-w_half_ind_rot(1);
% 
% % Find total energy in peak
% w_e_acc = sum(w_lin_acc.^2)./10^10;
% w_e_rot = sum(w_rot_vel.^2)./10^10;
% 
% moreFeatures = cat(1,moreFeatures,w_val_acc,w_val_rot,w_ind_acc,w_ind_rot, ...
%                w_fwhm_acc,w_fwhm_rot,w_e_acc,w_e_rot);


% concatenate everything into features vector
features = [dists ; ratios ; fpks; moreFeatures]';




