function [feature_ind,val] = feature_select(allFeatures,labelType,dataType,method,featureParam)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Inputs:
% allFeatures - feature structure
% labelType - string corresponding to label type
% method - classification method; options are 'knn','lda','nb','svm',
% featureParam - vector of parameters needed for running method
%
% feature_select will determine the best feature combination for a given
% classifier using a forward search method.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clc;

% Mirror Pitching/Batting Data if necessary:

if strcmp(labelType,'location')==1 || strcmp(labelType,'horiz_loc')==1
  if strcmp(dataType,'pitch') == 1  
    for p = 1:length(allFeatures.labels.handed)
      if allFeatures.labels.handed == 1
        allFeatures.labels.location(p) = mirror_pitch(allFeatures.labels.location(p));    
      end;
    end;
  elseif strcmp(dataType,'bat') == 1
    for q = 1:length(allFeatures.labels.handed)
      if allFeatures.labels.handed == 1
        allFeatures.labels.location(q) = mirror_pitch(allFeatures.labels.location(q));    
      end;
    end;
  else
    fprintf('Invalid dataType.\n');
    return;
  end;
end;

% Perform 

feature_ind = [];
maxno = 21;
improvement = 1;
m = 1;

while m < maxno %&& improvement(end) > 1e-4
    
  for i = 1:size(allFeatures.featureMatrix,2)
    if length(find(feature_ind==i))==0
      feature_ind_i = cat(2,feature_ind,i);
      if strcmp('knn',method) == 1
        err1(i) = execKNN(allFeatures,feature_ind_i,labelType,featureParam,'euclidean');
      elseif strcmp('lda',method) == 1
        err1(i) = execLDA(allFeatures,feature_ind_i,labelType);
      elseif strcmp('nb',method) == 1
        err1(i) = execNaiveBayes(allFeatures, feature_ind_i,labelType);
      elseif strcmp('svm',method) == 1
        err1(i) = execSVM(allFeatures,feature_ind_i,labelType); 
      end;
    else
      err1(i) = 10;   % ensure we do not repeat indices
    end;  
  end;
  [val1,ind1] = min(err1);
  fprintf('Feature Number = %g, Classification Error = %f.\n',ind1,val1);
  feature_ind = cat(2,feature_ind,ind1);
  val(m) = val1;
  if m == 1
    improvement = 1-val1;
  else  
    improvement = cat(1,improvement,val(m-1)-val(m));
  end;
  m = m+1;  
end; 

if strcmp(method,'knn') == 1
  title = ['features/features_' dataType '_' labelType '_' method num2str(featureParam) '.mat'];
  feature_info = struct('dataType',dataType,'labelType',labelType,'method',method,'k',featureParam);
  save(title,'feature_ind','val','feature_info');
else
  title = ['features/features_' dataType '_' labelType '_' method '.mat'];  
  feature_info = struct('dataType',dataType,'labelType',labelType,'method',method);
  save(title,'feature_ind','val','feature_info');
end;