function [feature_ind,val] = feature_select_new(allFeatures,labelType,dataType,method,featureParam)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Inputs:
% allFeatures - feature structure
% labelType - string corresponding to label type
% method - classification method; options are 'knn','lda','nb','svm',
% featureParam - vector of parameters needed for running method
%
% feature_select will determine the best feature combination for a given
% classifier using a forward search method.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clc;

% Mirror Pitching/Batting Data if necessary:

if strcmp(labelType,'location')==1 || strcmp(labelType,'horiz_loc')==1
  if strcmp(dataType,'pitch') == 1  
    for p = 1:length(allFeatures.labels.handed)
      if allFeatures.labels.handed == 1
        allFeatures.labels.location(p) = mirror_pitch(allFeatures.labels.location(p));    
      end;
    end;
  elseif strcmp(dataType,'bat') == 1
    for q = 1:length(allFeatures.labels.handed)
      if allFeatures.labels.handed == 1
        allFeatures.labels.location(q) = mirror_pitch(allFeatures.labels.location(q));    
      end;
    end;
  else
    fprintf('Invalid dataType.\n');
    return;
  end;
end;

switch labelType
  case 'location'
    labs = allFeatures.labels.location;
  case 'type'
    labs = allFeatures.labels.type;
  case 'playerID'
    labs = allFeatures.labels.player_ID; 
  case 'fastnot'
    labs = allFeatures.labels.fastnot;
  case 'vert_loc'
    labs = allFeatures.labels.vert_loc;
  case 'horiz_loc'
    labs = allFeatures.labels.horiz_loc; 
  case 'fast_chng_brk'
    labs = allFeatures.labels.fast_chng_brk; 
end;

knn_fun = @(XT,yT,Xt,yt)(length(find(abs(yt-knnclassify(Xt,XT,yT,1))>0)));
lda_fun = @(XT,yT,Xt,yt)(length(find(abs(yt-classify(Xt,XT,yT))>0)));
nb1_fun = @(XT,yT,Xt,yt)(nb_fun(XT,yT,Xt,yt));
svm1_fun = @(XT,yT,Xt,yt)(runSVM_selection(XT,yT,Xt,yt,classNum));

if strcmp('knn',method) == 1
  [inmodel,history] = sequentialfs(knn_fun,allFeatures.featureMatrix,labs'); 
elseif strcmp('lda',method) == 1
  [inmodel,history] = sequentialfs(lda_fun,allFeatures.featureMatrix,labs');        
elseif strcmp('nb',method) == 1
  [inmodel,history] = sequentialfs(nb1_fun,allFeatures.featureMatrix,labs');        
elseif strcmp('svm',method) == 1
  [inmodel,history] = sequentialfs(svm1_fun,allFeatures.featureMatrix,labs');        
end;

feature_ind = find(inmodel);
val         = history;

if strcmp(method,'knn') == 1
  title = ['features/new_' dataType '_' labelType '_' method num2str(featureParam) '.mat'];
  feature_info = struct('dataType',dataType,'labelType',labelType,'method',method,'k',featureParam);
  save(title,'feature_ind','val','feature_info');
else
  title = ['features/new_' dataType '_' labelType '_' method '.mat'];  
  feature_info = struct('dataType',dataType,'labelType',labelType,'method',method);
  save(title,'feature_ind','val','feature_info');
end;