function allFeatures = extractAllFeatures(allData, dataType)
% allFeatures = extractAllFeatures(allData, dataType)
%
% Extracts all features from cell array allData and return them in a matrix
%
% Output: 
%   allFeatures = structure containing matrix of features by column, and
%                 all labels
%
% Inputs:
%   allData     = data cell array, as documented in getAll***Data.m
%   dataType    = 'pitch' or 'swing'
%

featureMatrix = [];

if(strcmp(dataType, 'pitch'))
    for i = 1:length(allData)
        fprintf('extracting features for example %i of %i...',i,length(allData))
        features = extractFeatures(allData{i}.rawData,'pitch');
        featureMatrix = [featureMatrix; features.features];
        allFeatures.labels.type(i) = allData{i}.pitchType;
        allFeatures.labels.location(i) = allData{i}.location;
        allFeatures.labels.player_ID(i) = allData{i}.player_ID;
        allFeatures.labels.handed(i) = allData{i}.handed;
        allFeatures.gesture_ID(i) = allData{i}.gesture_ID;
        allFeatures.TOC = features.TOC;
        clear features
        fprintf('done.\n')
    end
elseif(strcmp(dataType, 'swing'))
    for i = 1:length(allData)
        fprintf('extracting features for example %i of %i...',i,length(allData))
        features = extractFeatures(allData{i}.rawData,'swing', allData{i}.swingInfo.impact);
        % get pre-computed swing info data and tack it on to features vector:
        features.features = [features.features, (allData{i}.swingInfo.impact - allData{i}.swingInfo.start), (allData{i}.swingInfo.stop - allData{i}.swingInfo.impact) ];
        featureMatrix = [featureMatrix; features.features];
        allFeatures.labels.type(i) = allData{i}.type;
        allFeatures.labels.location(i) = allData{i}.location;
        allFeatures.labels.player_ID(i) = allData{i}.player_ID;
        allFeatures.labels.handed(i) = allData{i}.handed;
        allFeatures.gesture_ID(i) = allData{i}.gesture_ID;
        allFeatures.TOC = features.TOC;
        clear features
        fprintf('done.\n')
    end
    allFeatures.TOC{199} = 'dist_impact_start';
    allFeatures.TOC{200} = 'dist_impact_end';
else
    fprintf('No such data type (%s)\n', dataType)
end

allFeatures.featureMatrix = featureMatrix;
