% This script serves as a wrapper for running SFS with 10-fold
% cross-validation on all data classification problems with all different
% classification methods.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Pitching
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all;
load features/allPitchFeaturesNOCURVES;

% Type

for k = 1:2:11
  feature_select_new(allPitchFeatures,'type','pitch','knn',k);
end;

feature_select_new(allPitchFeatures,'type','pitch','lda');
%feature_select_new(allPitchFeatures,'type','pitch','nb');

% Need to do for 1:7

for j = 1:7
  if j ~= 3
    feature_select_new(allPitchFeatures,'type','pitch','svm',j)
  end;
  keyboard
end;


clear all;
load features/allPitchFeatures;

% Location

for k = 1:2:11
  feature_select_new(allPitchFeatures,'location','pitch','knn',k);
end;

feature_select_new(allPitchFeatures,'location','pitch','lda');
%feature_select_new(allPitchFeatures,'location','pitch','nb');
% For now omit svm here

% Player ID

feature_select_new(allPitchFeatures,'playerID','pitch','lda');
%feature_select_new(allPitchFeatures,'playerID','pitch','nb');

for k = 1:2:11
  feature_select_new(allPitchFeatures,'playerID','pitch','knn',k);
end;

player_list = unique(allPitchFeatures.labels.player_ID)

for m = 1:length(player_list)
  feature_select_new(allPitchFeatures,'playerID','pitch','svm',player_list(m))
end;  

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Batting
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all;
load features/allSwingFeatures;

% Location

feature_select_new(allSwingFeatures,'location','bat','lda');
%feature_select_new(allSwingFeatures,'location','bat','nb');

for k = 1:2:11
  feature_select_new(allSwingFeatures,'location','bat','knn',k);
end;

for m = 1:3
  feature_select_new(allSwingFeatures,'location','bat','svm',m)
end;  


% Player ID

feature_select_new(allSwingFeatures,'playerID','bat','lda');
%feature_select_new(allSwingFeatures,'playerID','bat','nb');

for k = 1:2:11
  feature_select_new(allSwingFeatures,'playerID','bat','knn',k);
end;

player_list = unique(allSwingFeatures.labels.player_ID)

for m = 1:length(player_list)
  feature_select_new(allSwingFeatures,'playerID','bat','svm',player_list(m))
end;  


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Subsets
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

create_subsets;

% Fastball vs. Everything Else

for k = 1:2:11
  feature_select_new(allPitchFeatures,'fastnot','pitch','knn',k);
end;
feature_select_new(allPitchFeatures,'fastnot','pitch','lda');
feature_select_new(allPitchFeatures,'fastnot','pitch','nb');
feature_select_new(allPitchFeatures,'fastnot','pitch','svm',1)


% Vertical Location
feature_select_new(allPitchFeatures,'vert_loc','pitch','lda');
feature_select_new(allPitchFeatures,'vert_loc','pitch','nb');
for k = 1:2:11
  feature_select_new(allPitchFeatures,'vert_loc','pitch','knn',k);
end;
for m = 1:3
  feature_select_new(allPitchFeatures,'vert_loc','pitch','svm',m)
end;


% Horizontal Location
feature_select_new(allPitchFeatures,'horiz_loc','pitch','lda');
feature_select_new(allPitchFeatures,'horiz_loc','pitch','nb');
for k = 1:2:11
  feature_select_new(allPitchFeatures,'horiz_loc','pitch','knn',k);
end;
for m = 1:3
  feature_select_new(allPitchFeatures,'horiz_loc','pitch','svm',m)
end;


% Fastball, Changeup, Breaking Ball

fastc = []; changec = []; breakc = [];

for w = 1:length(allPitchFeatures.labels.type)
  if allPitchFeatures.labels.type == 1
    fastc = cat(1,fastc,w);
  elseif allPitchFeatures.labels.type == 2
    changec = cat(1,changec,w);
  elseif allPitchFeatures.labels.type == 3
    breakc = cat(1,breakc,w);
  end;
end;

keep_ind = sort(cat(1,fastc,changec,breakc));

allPitchFeatures.featureMatrix = allPitchFeatures.featureMatrix(keep_ind,:);

fast_chng_brk          = ones(1,length(keep_ind));    
fast_chng_brk(changec) = 2;
fast_chng_brk(breakc)  = 3;
allPitchFeatures.labels.fast_chng_brk = fast_chng_brk;

feature_select_new(allPitchFeatures,'fast_chng_brk','pitch','lda');
%feature_select_new(allPitchFeatures,'fast_chng_brk','pitch','svm');
for k = 1:2:11
  feature_select_new(allPitchFeatures,'fast_chng_brk','pitch','knn',k);
end;
for m = 1:3
  feature_select_new(allPitchFeatures,'fast_chng_brk','pitch','svm',m)
end;

feature_select_new(allPitchFeatures,'fast_chng_brk','pitch','nb');
