function opp_acc_out = runSVM_selection(trainFeaturesMat, trainLabels, testFeaturesMat, testLabels, toClassify)
% run SVM on a given selection of features for a given label type, and
% return the true positive and false positive rates for each class (as
% measured using leave-one-out cross-validation).
%
% SVM is a binary classifier, and therefore the performance is per class
% (as opposed to over the whole set).
%
% Outputs: 
%   opp_acc_out     = classifier error on testing set. 
%
% Inputs:
%   allFeatures     = all features structure (project standard)
%   featuresToUse   = vectors of features to select from all features
%   labelType       = which label to train/test on:
%           'type'
%           'location'
%           'playerID'

addpath ./LibSVM32\LibSVM32

svmTrainLabels = trainLabels;
svmTrainLabels(svmTrainLabels~=toClassify)=-1;
svmTrainLabels(svmTrainLabels==toClassify)= 1;

svmTestLabels = testLabels;
svmTestLabels(svmTestLabels~=toClassify)=-1;
svmTestLabels(svmTestLabels==toClassify)= 1;

model = svmtrain(svmTrainLabels, trainFeaturesMat, '-t 2 -c 50');
[predicted_label, accuracy, decision_values] = svmpredict(svmTestLabels,testFeaturesMat, model);

opp_acc_out = 1-accuracy(1)/100;
% found = find(predicted_label==1);
% reality = find(svmTestLabels==1);
% fp = 0;
% tp = 0;
% for i = 1:length(found)
%     if( find(reality == found(i)))
%         tp = tp + 1;
%     else
%         fp = fp + 1;
%     end
% end
% 
% tpRate(j) = tp ./ length(reality);
% fpRate(j) = fp ./ (length(labels)-length(reality));
% 
% 
% tpRate = [uniqueLabels' tpRate'];
% fpRate = [uniqueLabels' fpRate'];





