% get all pitcher data and labels and put them into cell array allPitches
%
% allPitches{i}                 pulls up everything for example i
% allPitches{i}.rawData         raw data
% allPitches{i}.gesture_ID      gesture ID
% allPitches{i}.player_ID       player ID
% allPitches{i}.session_ID      session ID
% allPitches{i}.pitchType       pitch type (labels documented below)
% allPitches{i}.location        pitch location (labels documented below)
% allPitches{i}.handed          player handedness (L=1, R=2)

% Label definitions:
%       pitch types:
%           0 = UNKNOWN
%           1 = FAST
%           2 = CHANGE
%           3 = CURVE
%           4 = SLIDER
%           5 = 2_SEAM
%           6 = 4_SEAM
%           7 = BREAK
%
%       pitch locations:
%           10 1 2 3 13 
%           11 4 5 6 14 
%           12 7 8 9 15     (16 = dirt, not downloaded)
%                       

clear all

handedness = 'LR';
locLabels = [10 1 2 3 13 11 4 5 6 14 12 7 8 9 15];
gestures = [];
players = [];
sessions = [];
pitchTypes = [];
locations = [];
handed = [];
for i = 1:7
    for j = 1:length(locLabels)
        for k = 1:2
            [g_id p_id s_id] = getGestures(1,i,j,handedness(k));
            gestures = [gestures ; g_id];
            players = [players ; p_id];
            sessions = [sessions ; s_id];
            handed = [handed ; ones(length(g_id),1).*k];
            pitchTypes = [pitchTypes ; ones(length(g_id),1).*i];
            locations = [locations ; ones(length(g_id),1).*j];
            clear g_id p_id s_id
        end
    end
end

% Data with problems:
discard_ext = [918 815 861 926 522 507 556 475 930 884 956 414 1166 1259 ... 
    1187 1183 1213 591 945 1141 1106 1107 1108 1109 1110 1112 1113 1114 ... 
    1115 1116 1117 1119 1121 1122 1123 1125 1126 1127 1129 1130 1133 1135 ...
    1136 1138 1139 1143 1144 1146 1148 1150 1151 1154 1156 1001 1003 1005 ...
    1007 1009 1013 1015 1017 1021 1025 1027 1031 1033 1037 1039 1043 1047 ...
    1049 1053 1055 1059 1065 1071 1073 1083 1087 1091 1093 1095 1852 1853 ...
    1854 1855 1856 538 199]';

% Pitchers we need to ignore
discard_1 = getGestures(1,'all','all',28); 
discard_2 = getGestures(1,'all','all',29);
discard_3 = getGestures(1,'all','all',30);

discard = cat(1,discard_ext,discard_1,discard_2,discard_3);
discard = sort(discard);
discard(find(diff(discard) == 0)) = [];  % remove repeats

for i = 1:length(discard)
  ind = find(gestures == discard(i));
  gestures(ind) = [];
  players(ind)  = [];
  sessions(ind) = [];
  pitchTypes(ind) = [];
  locations(ind) = [];
end;

for i = 1:length(gestures)
    % raw data:
    [hand,forearm,upper_arm,chest,waist] = getData(gestures(i));
    allPitches{i}.rawData.hand = hand;
    allPitches{i}.rawData.forearm = forearm;
    allPitches{i}.rawData.upper_arm = upper_arm;
    allPitches{i}.rawData.chest = chest;
    allPitches{i}.rawData.waist = waist;
    
    % metadata:
    allPitches{i}.gesture_ID = gestures(i);
    allPitches{i}.player_ID = players(i);
    allPitches{i}.session_ID = sessions(i);
    allPitches{i}.pitchType = pitchTypes(i);
    allPitches{i}.location = locations(i);
    allPitches{i}.handed = handed(i);
    
    clear hand forearm upper_arm chest waist
end







