% get all pitcher data and labels and put them into cell array allPitches
%
% allSwings{i}                  pulls up everything for example i
% allSwings{i}.rawData          raw data
% allSwings{i}.gesture_ID       gesture ID
% allSwings{i}.player_ID        player ID
% allSwings{i}.session_ID       session ID
% allSwings{i}.types            swing type (labels documented below)
% allSwings{i}.location         swing location (labels documented below)
% allSwings{i}.swingInfo.start  hit start time (from database)
% allSwings{i}.swingInfo.stop   hit end time (from database)
% allSwings{i}.swingInfo.impact impact time (from database)
% allSwings{i}.handed           player handedness (L=1, R=2)
%
% Label definitions:
%       swing types:
%           0 = STRIKE  (not downloaded)
%           1 = FREE    (not downloaded)
%           2 = TEE
%           3 = SOFT
%           4 = BP
%           5 = NORMAL
%
%       locations:
%           1 = center
%           2 = left
%           3 = right
%                       

clear all

handedness = 'LR';
gestures = [];
players = [];
sessions = [];
types = [];
locations = [];
handed = [];
for i = 2:5
    for j = 1:3
        for k = 1:2
            [g_id p_id s_id] = getGestures(2,i,j,handedness(k));
            gestures = [gestures ; g_id];
            players = [players ; p_id];
            sessions = [sessions ; s_id];
            handed = [handed ; ones(length(g_id),1).*k];
            types = [types ; ones(length(g_id),1).*i];
            locations = [locations ; ones(length(g_id),1).*j];
            clear g_id p_id s_id
        end
    end
end

% Data with problems:
discard_ext = [];
 
% Hitters we need to ignore
discard_1 = getGestures(1,'all','all',19); 
discard_2 = getGestures(1,'all','all',26);

discard = cat(1,discard_ext,discard_1,discard_2);
discard = sort(discard);
discard(find(diff(discard) == 0)) = [];  % remove repeats

for i = 1:length(discard)
  ind = find(gestures == discard(i));
  gestures(ind) = [];
  players(ind)  = [];
  sessions(ind) = [];
  types(ind) = [];
  locations(ind) = [];
end;

for i = 1:length(gestures)
    % raw data:
    [hand,forearm,upper_arm,chest,waist] = getData(gestures(i));
    allSwings{i}.rawData.hand = hand;
    allSwings{i}.rawData.forearm = forearm;
    allSwings{i}.rawData.upper_arm = upper_arm;
    allSwings{i}.rawData.chest = chest;
    allSwings{i}.rawData.waist = waist;
    
    % metadata:
    allSwings{i}.gesture_ID = gestures(i);
    allSwings{i}.player_ID = players(i);
    allSwings{i}.session_ID = sessions(i);
    allSwings{i}.type = types(i);
    allSwings{i}.location = locations(i);
    allSwings{i}.handed = handed(i);
    
    % get swing info from database:
    [start1,stop1,impact1] = getSwingInfo(gestures(i));
    allSwings{i}.swingInfo.start = start1;
    allSwings{i}.swingInfo.stop = stop1;
    allSwings{i}.swingInfo.impact = impact1;
    
    clear hand forearm upper_arm chest waist
end







