function [idx,val,mxy] = compute_mutual_info(features,labels)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Inputs:
% features - rows are samples, columns are features (allFeatures.featureMatrix)
% labels   - column vector of labels assigned to each sample.
%
% Outputs:
% idx      - list of features with most mutual information in descending order
% val      - mutual information values corresponding to idx 
% mxy      - mutual information in original order
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

num_class = length(unique(labels));  
  
py = est_pdf(labels,num_class);

for i = 1:(size(features,2))    
  px  = est_pdf(features(:,i),20);
  pxy = est_joint(features(:,i),labels,20,num_class);

  arglog = pxy./((px*ones(1,length(py))).*(ones(length(px),1)*py));  
  output = pxy.*log2(arglog);
  
  mxy(i) = sum(output(~isnan(output)));

end;    

[val,idx] = sort(mxy,'descend');

plot(mxy,'linewidth',2)
grid on;
title('Mutual Information');
xlabel('Feature Number');
ylabel('Mutual Information with Labels');