% Wrapper script for computing mutual information

% Batting

clear all; close all; clc;

load features/allSwingFeatures;

location = allSwingFeatures.labels.location;
features = allSwingFeatures.featureMatrix;

for j=1:length(allSwings);  
  if allSwingFeatures.labels.handed == 1
    location(j) = mirror_bat(location(j));    
  end;
end;

[idx_bat1,list_bat1,mi_bat1] = compute_mutual_info(features,location);

[idx_bat2,list_bat2,mi_bat2] = compute_mutual_info(features,allFeatures.labels.player_ID);

figure;
plot(mi_bat1,'linewidth',2);
hold on;
plot(mi_bat2,'r','linewidth',2);
legend('Hit Location','Player ID','location','northwest');
title('Mutual Information (Batting)');
xlabel('Feature Number');
ylabel('Mutual Information');

% Pitching

% First do over all pitch types/locations

load data/allPitchesNOCURVES;

features  = allFeatures.featureMatrix;
location  = allFeatures.labels.location;
type      = allFeatures.labels.type;
player_id = allFeatures.labels.player_ID;

[idx_pitch1,list_pitch1,mi_pitch1] = compute_mutual_info(features,type);

load data/allPitchFeatures;

features  = allFeatures.featureMatrix;
location  = allFeatures.labels.location;
type      = allFeatures.labels.type;
player_id = allFeatures.labels.player_ID;

for j=1:length(allPitches);  
  if allPitchFeatures.labels.handed == 1
    location(j) = mirror_pitch(location(j));    
  end;
end;

[idx_pitch2,list_pitch2,mi_pitch2] = compute_mutual_info(features,location);
[idx_pitch3,list_pitch3,mi_pitch3] = compute_mutual_info(features,player_id);

figure;
plot(mi_pitch1,'linewidth',2);
hold on;
plot(mi_pitch2,'r','linewidth',2);
plot(mi_pitch3,'k','linewidth',2);
grid on;
legend('Pitch Type', 'Pitch Location','Player ID','location','northwest');
title('Mutual Information (Pitching)');
xlabel('Feature Number');
ylabel('Mutual Information');

% Next do subsets:

% Fastball vs. everything else:

fast_type = type;
fast_type(find(type ~= 1)) = 0;

[idx_pitch4,list_pitch4,mi_pitch4] = compute_mutual_info(features,fast_type);


% Fastball, Changeup, Breaking Ball 

ind31 = union(find(type==1),find(type==2));
ind3 = sort(union(ind31,find(type==7)));
features3 = features(ind3,:);
types3    = type(ind3);

[idx_pitch5,list_pitch5,mi_pitch5] = compute_mutual_info(features3,types3);

% Location - Top, Middle, Bottom

vert_loc = location;

upper = []; middle = []; lower = [];

for m = 1:length(location)
  if location(m)==10 || location(m)==1 || location(m)==2 || location(m)== 3 || location(m)==13
    upper = cat(1,upper,m);
  elseif location(m)==11 || location(m)==4 || location(m)==5 || location(m)== 6 || location(m)==14
    middle = cat(1,middle,m);
  elseif location(m)==12 || location(m)==7 || location(m)==8 || location(m)==9 || location(m)==15
    lower = cat(1,lower,m);
  else
    fprintf('error');
    return;
  end;
end;    
    
vert_loc(upper) = 1; vert_loc(middle) = 2; vert_loc(lower) = 3;

[idx_pitch6,list_pitch6,mi_pitch6] = compute_mutual_info(features3,vert_loc);

% Location - Left, Center, Right

left = []; center = []; right = [];

for n = 1:length(location)
  if location(n)==10||location(n)==1||location(n)==4||location(n)==11||location(n)==7||location(n)==12
    left = cat(1,left,n);
  elseif location(n)==2||location(n)==5||location(n)==8
    center = cat(1,center,n);
  elseif location(n)==3||location(n)==13||location(n)==6||location(n)==14||location(n)==9||location(n)==15
    right = cat(1,right,n);
  else
    fprintf('error');
    return;
  end;
end;    

horiz_loc = location;

horiz_loc(left) = 1; horiz_loc(center) = 2; horiz_loc(right) = 3;

[idx_pitch7,list_pitch7,mi_pitch7] = compute_mutual_info(features,horiz_loc);

save('mi.mat','idx_*','list_*','mi_*');

